@@ -12,26 +12,26 @@ def validate_fields(identifiers: List[str], field_sets: List[List[SusField]]) ->
         for f1 in fields:
             # optional values mod 256
             if f1.optional != None and f1.optional >= 256:
-                diag.append(Diagnostic([f1.location], DiagLevel.WARN,
+                diag.append(Diagnostic([f1.location], DiagLevel.WARN, 8,
                     f"Optional value '{f1.optional}' will be taken mod 256 ('{f1.optional % 256}')"))
                 f1.optional %= 256
 
             # the fields within one set shouldn't have matching names
             equal = [f2 for f2 in fields if f2.name == f1.name]
             if len(equal) > 1:
-                diag.append(Diagnostic([f.location for f in equal], DiagLevel.ERROR,
+                diag.append(Diagnostic([f.location for f in equal], DiagLevel.ERROR, 9,
                     f"Multiple fields with matching names '{f1.name}'"))
             
             # or values
             equal = [f2 for f2 in fields if f2.optional == f1.optional and f1.optional != None]
             if len(equal) > 1:
-                diag.append(Diagnostic([f.location for f in equal], DiagLevel.ERROR,
+                diag.append(Diagnostic([f.location for f in equal], DiagLevel.ERROR, 10,
                     f"Multiple fields with matching opt() values '{f1.optional}'"))
 
             # validate the type
             type_err = f1.type_.find_errors(identifiers)
             if type_err != None:
-                diag.append(Diagnostic([f1.type_.location], DiagLevel.ERROR, type_err))
+                diag.append(Diagnostic([f1.type_.location], DiagLevel.ERROR, 11, type_err))
 
     return diag
 
@@ -51,8 +51,8 @@ def combine(things: List[SusThing]) -> Tuple[list[SusThing], list[Diagnostic]]:
             # diagnose redefinitions
             fine = True
             for thing2 in with_matching_name:
-                if not isinstance(thing1, (SusEnum, SusBitfield)):
-                    diag.append(Diagnostic([t.location for t in with_matching_name], DiagLevel.ERROR,
+                if type(thing1) != type(thing2) or not isinstance(thing1, (SusEnum, SusBitfield)):
+                    diag.append(Diagnostic([t.location for t in with_matching_name], DiagLevel.ERROR, 12,
                         f"Redefinition of '{thing1.name}' (only enums and bitfields can be combined)"))
                     fine = False
 
@@ -60,7 +60,7 @@ def combine(things: List[SusThing]) -> Tuple[list[SusThing], list[Diagnostic]]:
                 # match sizes
                 if not all([t.size == thing1.size for t in with_matching_name]):
                     diag.append(Diagnostic([t.location for t in with_matching_name],
-                        DiagLevel.ERROR, "Can't combine things of different sizes"))
+                        DiagLevel.ERROR, 13, "Can't combine things of different sizes"))
 
                 # record members of enums and mitfields
                 opt_members = []
@@ -83,14 +83,14 @@ def combine(things: List[SusThing]) -> Tuple[list[SusThing], list[Diagnostic]]:
             maximum = (thing1.size * 8 if isinstance(thing1, SusBitfield) else 256 ** thing1.size) - 1
             for member in thing1.members:
                 if member.value > maximum:
-                    diag.append(Diagnostic([member.location], DiagLevel.WARN,
+                    diag.append(Diagnostic([member.location], DiagLevel.WARN, 8,
                         f"Member value '{member.value}' overflow (max '{maximum}')"))
 
         if isinstance(thing1, (SusEntity, SusMethod)) and thing1.value > 127:
-            diag.append(Diagnostic([thing1.location], DiagLevel.WARN, f"Value '{thing1.value}' overflow (max '127')"))
+            diag.append(Diagnostic([thing1.location], DiagLevel.WARN, 8, f"Value '{thing1.value}' overflow (max '127')"))
 
         if isinstance(thing1, SusConfirmation) and thing1.value > 15:
-            diag.append(Diagnostic([thing1.location], DiagLevel.WARN, f"Value '{thing1.value}' overflow (max '15')"))
+            diag.append(Diagnostic([thing1.location], DiagLevel.WARN, 8, f"Value '{thing1.value}' overflow (max '15')"))
 
     log.verbose(f"Combined {len(things)} definitions into {len(out)} things", "linker")
     return out, diag
@@ -106,10 +106,10 @@ def validate_method_meta(things: List[SusThing], method_sets: List[List[SusMetho
         for method in m_set:
             for conf in method.confirmations:
                 if conf not in confirmations:
-                    diag.append(Diagnostic([method.location], DiagLevel.ERROR, f"Undefined confirmation '{conf}'"))
+                    diag.append(Diagnostic([method.location], DiagLevel.ERROR, 14, f"Undefined confirmation '{conf}'"))
 
             if len(method.errors) > 0 and len(errors) == 0:
-                diag.append(Diagnostic([method.location], DiagLevel.WARN,
+                diag.append(Diagnostic([method.location], DiagLevel.WARN, 15,
                     "No 'ErrorCode' enum defined. Include 'impostor.sus' or use a custom definition"))
                 continue
             if len(method.errors) == 0:
@@ -118,7 +118,7 @@ def validate_method_meta(things: List[SusThing], method_sets: List[List[SusMetho
 
             for err in method.errors:
                 if err not in error_names:
-                    diag.append(Diagnostic([method.location], DiagLevel.ERROR, f"Undefined error code '{err}'"))
+                    diag.append(Diagnostic([method.location], DiagLevel.ERROR, 16, f"Undefined error code '{err}'"))
     
     return diag
 
@@ -129,30 +129,30 @@ def validate_values(entities: List[SusEntity], method_sets: List[List[SusMethod]
     for thing in entities:
         matching = [t for t in entities if t.value == thing.value]
         if len(matching) != 1:
-            diag.append(Diagnostic([t.location for t in matching], DiagLevel.ERROR,
+            diag.append(Diagnostic([t.location for t in matching], DiagLevel.ERROR, 17,
                 f"Multiple entities with matching values '{thing.value}'"))
 
         # check ID field
         id_field = [f for f in thing.fields if f.name == "id"]
         if not id_field:
-            diag.append(Diagnostic([thing.location], DiagLevel.WARN, f"No 'id' field"))
+            diag.append(Diagnostic([thing.location], DiagLevel.WARN, 18, f"No 'id' field"))
         else:
             id_field = id_field[0]
             t = id_field.type_
             if t.name != "Int" or len(t.args) != 1 or t.args[0] != 8:
-                diag.append(Diagnostic([id_field.location], DiagLevel.WARN, f"The 'id' field is not an Int(8)"))
+                diag.append(Diagnostic([id_field.location], DiagLevel.WARN, 18, f"The 'id' field is not an Int(8)"))
 
     for m_set in method_sets:
         for method in m_set:
             matching = [t for t in m_set if t.value == method.value]
             if len(matching) != 1:
-                diag.append(Diagnostic([t.location for t in matching], DiagLevel.ERROR,
+                diag.append(Diagnostic([t.location for t in matching], DiagLevel.ERROR, 17,
                     f"Multiple methods with matching values '{method.value}'"))
 
     for thing in confirmations:
         matching = [t for t in confirmations if t.value == thing.value]
         if len(matching) != 1:
-            diag.append(Diagnostic([t.location for t in matching], DiagLevel.ERROR,
+            diag.append(Diagnostic([t.location for t in matching], DiagLevel.ERROR, 17,
                 f"Multiple confirmations with matching values '{thing.value}'"))
     
     return diag
